<?php
/*
Plugin Name: WooCommerce Feed Compari.ro
Plugin URI: https://tutorialewebsite.ro
Description: Creează un feed XML pentru Compari.ro.
Version: 1.0
Author: Bădoi Alexandru
Author URI: https://tutorialewebsite.ro
License: GPL2
*/

add_action('init', function () {
    add_rewrite_rule('feed/compari\.xml$', 'index.php?compari_feed=1', 'top');
    add_rewrite_tag('%compari_feed%', '1');
});

add_action('template_redirect', function () {
    if (get_query_var('compari_feed') === '1') {
        header('Content-Type: application/xml; charset=utf-8');

        $products = wc_get_products([
            'status' => 'publish',
            'limit' => -1,
        ]);

        echo '<?xml version="1.0" encoding="UTF-8"?>';
        echo '<products>';

        foreach ($products as $product) {
            $product_id = $product->get_id();
            $product_name = htmlspecialchars($product->get_name());
            $product_url = htmlspecialchars($product->get_permalink());
            $image_url = wp_get_attachment_url($product->get_image_id());
            $price = wc_get_price_including_tax($product);
            $currency = get_woocommerce_currency();
            $availability = $product->is_in_stock() ? 'in stock' : 'out of stock';

            // Obține ierarhia corectă a categoriilor
            $categories = get_product_categories_hierarchy($product_id);
            $description = htmlspecialchars($product->get_short_description() ?: $product->get_description());

            echo '<product>';
            echo '<manufacturer>DeLonghi</manufacturer>'; // Modifică dacă este necesar
            echo '<id>' . $product_id . '</id>';
            echo '<name>' . $product_name . '</name>';
            echo '<description>' . $description . '</description>';
            echo '<url>' . $product_url . '</url>';
            echo '<image_url>' . $image_url . '</image_url>';
            echo '<price>' . $price . '</price>';
            echo '<currency>' . $currency . '</currency>';
            echo '<availability>' . $availability . '</availability>';
            echo '<category>' . $categories . '</category>';
            echo '</product>';
        }

        echo '</products>';
        exit;
    }
});

// Funcția pentru categorii ierarhizate
function get_product_categories_hierarchy($product_id) {
    $terms = get_the_terms($product_id, 'product_cat');
    if (!$terms || is_wp_error($terms)) {
        return '';
    }

    $hierarchical_categories = [];
    foreach ($terms as $term) {
        $ancestors = get_ancestors($term->term_id, 'product_cat');
        $ancestors = array_reverse($ancestors);
        $ancestor_names = [];

        foreach ($ancestors as $ancestor_id) {
            $ancestor = get_term($ancestor_id, 'product_cat');
            $ancestor_names[] = $ancestor->name;
        }

        $ancestor_names[] = $term->name;
        $hierarchical_categories[] = implode(' > ', $ancestor_names);
    }

    return implode(' | ', array_unique($hierarchical_categories));
}
